/*
	*
	* This file is taken from CoreStats <https://gitlab.com/cubocore/corestats>
	* Further modifications may be done as per the requirements of DesQ
	* All bug repots are to be filed with DesQ and not corestats
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* ( at your option ) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include "DesQUI.hpp"

/*
	*
	* DesQUsageGauge class
	*
	* DesQUsageGauge is designed to show the current DesQUsage of various system resources
	* like CPU, Network etc. It has a speedometer like design.
	*
	* A single DesQUsageGauge can show data in multiple segments: 4 segments for quad
	* core CPU, two segments for Network Up and Down, and so on
	*
*/

typedef QList<quint64> GaugeResourceValues;

class DESQUI_DLLSPEC DesQUsageGauge : public QWidget {
	Q_OBJECT

	public:
		enum Units {
			PERCENT = 0x218628,	 // Percentage
			SIZE,				   // Size, like KiB, TiB, etc
			SPEED				   // Speed, like MiB/s
		};

		DesQUsageGauge( QString resource, int segments, QWidget *parent );

		/* Maximum value */
		void setMax( quint64 max );

		/* Units */
		void setUnits( DesQUsageGauge::Units units );

		/* Labels for the legends */
		void setLabels( QStringList );

		/* Set the bar value */
		void setValues( GaugeResourceValues );

		QSize sizeHint();
		QSize minimumSizeHint();

		int minimumWidth();

	private:
		int mSegments;
		DesQUsageGauge::Units mUnits;
		QString resName;

		quint64 mMax;
		quint64 minWidth;

		GaugeResourceValues mValues;
		QStringList mLabels;

		int labelHeight = 0;

	protected:
		void paintEvent( QPaintEvent * );
};
